@@ -11,6 +11,7 @@
  *
  * @since 2.5.0
  */
+#[AllowDynamicProperties]
 class WP_Filesystem_Base {
 
 	/**
@@ -56,8 +57,10 @@ class WP_Filesystem_Base {
 	public function abspath() {
 		$folder = $this->find_folder( ABSPATH );
 
-		// Perhaps the FTP folder is rooted at the WordPress install.
-		// Check for wp-includes folder in root. Could have some false positives, but rare.
+		/*
+		 * Perhaps the FTP folder is rooted at the WordPress install.
+		 * Check for wp-includes folder in root. Could have some false positives, but rare.
+		 */
 		if ( ! $folder && $this->is_dir( '/' . WPINC ) ) {
 			$folder = '/';
 		}
@@ -129,14 +132,13 @@ class WP_Filesystem_Base {
 	 * @see WP_Filesystem_Base::wp_themes_dir()
 	 * @see WP_Filesystem_Base::wp_lang_dir()
 	 *
-	 * @param string $base The folder to start searching from.
-	 * @param bool   $echo True to display debug information.
-	 *                     Default false.
+	 * @param string $base    Optional. The folder to start searching from. Default '.'.
+	 * @param bool   $verbose Optional. True to display debug information. Default false.
 	 * @return string The location of the remote path.
 	 */
-	public function find_base_dir( $base = '.', $echo = false ) {
+	public function find_base_dir( $base = '.', $verbose = false ) {
 		_deprecated_function( __FUNCTION__, '2.7.0', 'WP_Filesystem_Base::abspath() or WP_Filesystem_Base::wp_*_dir()' );
-		$this->verbose = $echo;
+		$this->verbose = $verbose;
 		return $this->abspath();
 	}
 
@@ -151,13 +153,13 @@ class WP_Filesystem_Base {
 	 * @see WP_Filesystem_Base::wp_themes_dir()
 	 * @see WP_Filesystem_Base::wp_lang_dir()
 	 *
-	 * @param string $base The folder to start searching from.
-	 * @param bool   $echo True to display debug information.
+	 * @param string $base    Optional. The folder to start searching from. Default '.'.
+	 * @param bool   $verbose Optional. True to display debug information. Default false.
 	 * @return string The location of the remote path.
 	 */
-	public function get_base_dir( $base = '.', $echo = false ) {
+	public function get_base_dir( $base = '.', $verbose = false ) {
 		_deprecated_function( __FUNCTION__, '2.7.0', 'WP_Filesystem_Base::abspath() or WP_Filesystem_Base::wp_*_dir()' );
-		$this->verbose = $echo;
+		$this->verbose = $verbose;
 		return $this->abspath();
 	}
 
@@ -263,7 +265,7 @@ class WP_Filesystem_Base {
 
 		if ( $this->verbose ) {
 			/* translators: 1: Folder to locate, 2: Folder to start searching from. */
-			printf( "\n" . __( 'Looking for %1$s in %2$s' ) . "<br/>\n", $folder, $base );
+			printf( "\n" . __( 'Looking for %1$s in %2$s' ) . "<br />\n", $folder, $base );
 		}
 
 		$folder_parts     = explode( '/', $folder );
@@ -274,7 +276,7 @@ class WP_Filesystem_Base {
 		$files = $this->dirlist( $base );
 
 		foreach ( $folder_parts as $index => $key ) {
-			if ( $index == $last_index ) {
+			if ( $index === $last_index ) {
 				continue; // We want this to be caught by the next code block.
 			}
 
@@ -292,7 +294,7 @@ class WP_Filesystem_Base {
 
 				if ( $this->verbose ) {
 					/* translators: %s: Directory name. */
-					printf( "\n" . __( 'Changing to %s' ) . "<br/>\n", $newdir );
+					printf( "\n" . __( 'Changing to %s' ) . "<br />\n", $newdir );
 				}
 
 				// Only search for the remaining path tokens in the directory, not the full path again.
@@ -305,25 +307,31 @@ class WP_Filesystem_Base {
 			}
 		}
 
-		// Only check this as a last resort, to prevent locating the incorrect install.
-		// All above procedures will fail quickly if this is the right branch to take.
+		/*
+		 * Only check this as a last resort, to prevent locating the incorrect install.
+		 * All above procedures will fail quickly if this is the right branch to take.
+		 */
 		if ( isset( $files[ $last_path ] ) ) {
 			if ( $this->verbose ) {
 				/* translators: %s: Directory name. */
-				printf( "\n" . __( 'Found %s' ) . "<br/>\n", $base . $last_path );
+				printf( "\n" . __( 'Found %s' ) . "<br />\n", $base . $last_path );
 			}
 
 			return trailingslashit( $base . $last_path );
 		}
 
-		// Prevent this function from looping again.
-		// No need to proceed if we've just searched in `/`.
+		/*
+		 * Prevent this function from looping again.
+		 * No need to proceed if we've just searched in `/`.
+		 */
 		if ( $loop || '/' === $base ) {
 			return false;
 		}
 
-		// As an extra last resort, Change back to / if the folder wasn't found.
-		// This comes into effect when the CWD is /home/user/ but WP is at /var/www/....
+		/*
+		 * As an extra last resort, Change back to / if the folder wasn't found.
+		 * This comes into effect when the CWD is /home/user/ but WP is at /var/www/....
+		 */
 		return $this->search_for_folder( $folder, '/', true );
 
 	}
@@ -343,19 +351,19 @@ class WP_Filesystem_Base {
 	public function gethchmod( $file ) {
 		$perms = intval( $this->getchmod( $file ), 8 );
 
-		if ( ( $perms & 0xC000 ) == 0xC000 ) { // Socket.
+		if ( ( $perms & 0xC000 ) === 0xC000 ) { // Socket.
 			$info = 's';
-		} elseif ( ( $perms & 0xA000 ) == 0xA000 ) { // Symbolic Link.
+		} elseif ( ( $perms & 0xA000 ) === 0xA000 ) { // Symbolic Link.
 			$info = 'l';
-		} elseif ( ( $perms & 0x8000 ) == 0x8000 ) { // Regular.
+		} elseif ( ( $perms & 0x8000 ) === 0x8000 ) { // Regular.
 			$info = '-';
-		} elseif ( ( $perms & 0x6000 ) == 0x6000 ) { // Block special.
+		} elseif ( ( $perms & 0x6000 ) === 0x6000 ) { // Block special.
 			$info = 'b';
-		} elseif ( ( $perms & 0x4000 ) == 0x4000 ) { // Directory.
+		} elseif ( ( $perms & 0x4000 ) === 0x4000 ) { // Directory.
 			$info = 'd';
-		} elseif ( ( $perms & 0x2000 ) == 0x2000 ) { // Character special.
+		} elseif ( ( $perms & 0x2000 ) === 0x2000 ) { // Character special.
 			$info = 'c';
-		} elseif ( ( $perms & 0x1000 ) == 0x1000 ) { // FIFO pipe.
+		} elseif ( ( $perms & 0x1000 ) === 0x1000 ) { // FIFO pipe.
 			$info = 'p';
 		} else { // Unknown.
 			$info = 'u';
@@ -398,7 +406,7 @@ class WP_Filesystem_Base {
 	}
 
 	/**
-	 * Converts *nix-style file permissions to a octal number.
+	 * Converts *nix-style file permissions to an octal number.
 	 *
 	 * Converts '-rw-r--r--' to 0644
 	 * From "info at rvgate dot nl"'s comment on the PHP documentation for chmod()
@@ -407,8 +415,8 @@ class WP_Filesystem_Base {
 	 *
 	 * @since 2.5.0
 	 *
-	 * @param string $mode string The *nix-style file permission.
-	 * @return int octal representation
+	 * @param string $mode string The *nix-style file permissions.
+	 * @return string Octal representation of permissions.
 	 */
 	public function getnumchmodfromh( $mode ) {
 		$realmode = '';
@@ -664,10 +672,10 @@ class WP_Filesystem_Base {
 	 * @since 2.5.0
 	 * @abstract
 	 *
-	 * @param string $file Path to file or directory.
-	 * @return bool Whether $file exists or not.
+	 * @param string $path Path to file or directory.
+	 * @return bool Whether $path exists or not.
 	 */
-	public function exists( $file ) {
+	public function exists( $path ) {
 		return false;
 	}
 
@@ -716,10 +724,10 @@ class WP_Filesystem_Base {
 	 * @since 2.5.0
 	 * @abstract
 	 *
-	 * @param string $file Path to file or directory.
-	 * @return bool Whether $file is writable.
+	 * @param string $path Path to file or directory.
+	 * @return bool Whether $path is writable.
 	 */
-	public function is_writable( $file ) {
+	public function is_writable( $path ) {
 		return false;
 	}
 
@@ -827,18 +835,28 @@ class WP_Filesystem_Base {
 	 * @param bool   $recursive      Optional. Whether to recursively include file details in nested directories.
 	 *                               Default false.
 	 * @return array|false {
-	 *     Array of files. False if unable to list directory contents.
+	 *     Array of arrays containing file information. False if unable to list directory contents.
 	 *
-	 *     @type string $name        Name of the file or directory.
-	 *     @type string $perms       *nix representation of permissions.
-	 *     @type int    $permsn      Octal representation of permissions.
-	 *     @type string $owner       Owner name or ID.
-	 *     @type int    $size        Size of file in bytes.
-	 *     @type int    $lastmodunix Last modified unix timestamp.
-	 *     @type mixed  $lastmod     Last modified month (3 letter) and day (without leading 0).
-	 *     @type int    $time        Last modified time.
-	 *     @type string $type        Type of resource. 'f' for file, 'd' for directory.
-	 *     @type mixed  $files       If a directory and $recursive is true, contains another array of files.
+	 *     @type array $0... {
+	 *         Array of file information. Note that some elements may not be available on all filesystems.
+	 *
+	 *         @type string           $name        Name of the file or directory.
+	 *         @type string           $perms       *nix representation of permissions.
+	 *         @type string           $permsn      Octal representation of permissions.
+	 *         @type int|string|false $number      File number. May be a numeric string. False if not available.
+	 *         @type string|false     $owner       Owner name or ID, or false if not available.
+	 *         @type string|false     $group       File permissions group, or false if not available.
+	 *         @type int|string|false $size        Size of file in bytes. May be a numeric string.
+	 *                                             False if not available.
+	 *         @type int|string|false $lastmodunix Last modified unix timestamp. May be a numeric string.
+	 *                                             False if not available.
+	 *         @type string|false     $lastmod     Last modified month (3 letters) and day (without leading 0), or
+	 *                                             false if not available.
+	 *         @type string|false     $time        Last modified time, or false if not available.
+	 *         @type string           $type        Type of resource. 'f' for file, 'd' for directory, 'l' for link.
+	 *         @type array|false      $files       If a directory and `$recursive` is true, contains another array of
+	 *                                             files. False if unable to list directory contents.
+	 *     }
 	 * }
 	 */
 	public function dirlist( $path, $include_hidden = true, $recursive = false ) {
